pub struct Searcher { /* private fields */ }Implementations
Sourceimpl Searcher
impl Searcher
pub fn load(project_root: &Path, model_path: &Path) -> Result<Self>
Sourcepub fn load_from_index_dir(index_dir: &Path, model_path: &Path) -> Result<Self>
pub fn load_from_index_dir(index_dir: &Path, model_path: &Path) -> Result<Self>
Load a searcher from a specific index directory (for parent index use)
Sourcepub fn filter_by_path_prefix(&self, prefix: &Path) -> Result<Vec<i64>>
pub fn filter_by_path_prefix(&self, prefix: &Path) -> Result<Vec<i64>>
Filter results to files within a subdirectory prefix. Returns document IDs where file path starts with the given prefix.
Sourcepub fn filter_by_file_patterns(&self, patterns: &[String]) -> Result<Vec<i64>>
pub fn filter_by_file_patterns(&self, patterns: &[String]) -> Result<Vec<i64>>
Get document IDs matching the given file patterns using globset
Sourcepub fn filter_by_files(&self, files: &[String]) -> Result<Vec<i64>>
pub fn filter_by_files(&self, files: &[String]) -> Result<Vec<i64>>
Get document IDs for code units in the given files (exact match)
pub fn search( &self, query: &str, top_k: usize, subset: Option<&[i64]>, ) -> Result<Vec<SearchResult>>
pub fn num_documents(&self) -> usize